==> QupZilla-1.3.5.tar.gz: QupZilla-1.3.5/src/plugins/GreaseMonkey/translations/ja_JP.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>GM_AddScriptDialog</name>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="14"/>
        <source>GreaseMonkey Installation</source>
        <translation>GreaseMonkeyのインストール</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;GreaseMonkeyのインストール&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="73"/>
        <source>You are about to install this userscript into GreaseMonkey:</source>
        <translation>GreaseMonkeyスクリプトをダウンロードしようとしています:</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="86"/>
        <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
        <translation>&lt;b&gt;信頼できるソースからのみスクリプトをインストールしてください!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="96"/>
        <source>Are you sure you want to install it?</source>
        <translation>本当にこのスクリプトをインストールしますか?</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="114"/>
        <source>Show source code of script</source>
        <translation>スクリプトのソースを表示する</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="48"/>
        <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;実行するページ&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="52"/>
        <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;実行しないページ&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="82"/>
        <source>Cannot install script</source>
        <translation>スクリプトのインストールに失敗しました</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="85"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos;のインストールに成功しました</translation>
    </message>
</context>
<context>
    <name>GM_Downloader</name>
    <message>
        <location filename="../gm_downloader.cpp" line="144"/>
        <source>&apos;%1&apos; is already installed</source>
        <translation>&apos;%1&apos;は既にインストールされています</translation>
    </message>
</context>
<context>
    <name>GM_Manager</name>
    <message>
        <location filename="../gm_manager.cpp" line="172"/>
        <source>GreaseMonkey</source>
        <translation>GreaseMonkey</translation>
    </message>
</context>
<context>
    <name>GM_Notification</name>
    <message>
        <location filename="../gm_notification.ui" line="45"/>
        <source>This script can be installed with the GreaseMonkey plugin.</source>
        <translation>このスクリプトをGreasemonkeyでインストールできます。</translation>
    </message>
    <message>
        <location filename="../gm_notification.ui" line="65"/>
        <source>Install</source>
        <translation>インストール</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="49"/>
        <source>Cannot install script</source>
        <translation>スクリプトをインストールできません</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="57"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos;のインストールに成功しました</translation>
    </message>
</context>
<context>
    <name>GM_Settings</name>
    <message>
        <location filename="../settings/gm_settings.ui" line="14"/>
        <source>GreaseMonkey Scripts</source>
        <translation>GreaseMonkey スクリプト</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;GreaseMonkey スクリプト&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="73"/>
        <source>Double clicking script will show additional information</source>
        <translation>スクリプトをダブルクリックすると詳細が表示されます</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="153"/>
        <source>More scripts can be downloaded from</source>
        <translation>より多くのスクリプトは以下からダウンロードできます</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="196"/>
        <source>Open scripts directory</source>
        <translation>スクリプトの保存されたフォルダを開く</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="68"/>
        <source>Remove script</source>
        <translation>スクリプトを削除する</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="69"/>
        <source>Are you sure you want to remove &apos;%1&apos;?</source>
        <translation>本当&apos;%1&apos;を削除してよろしいですか?</translation>
    </message>
</context>
<context>
    <name>GM_SettingsScriptInfo</name>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="19"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="29"/>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="39"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="49"/>
        <source>Start at:</source>
        <translation>Beginnen bei:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="59"/>
        <source>Description:</source>
        <translation>説明:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="69"/>
        <source>Runs at:</source>
        <translation>実行するページ:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="79"/>
        <source>Does not run at:</source>
        <translation>実行しないページ:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.cpp" line="27"/>
        <source>Script Details of %1</source>
        <translation>%1の詳細を表示する</translation>
    </message>
</context>
</TS>

==> QupZilla-1.4.3.tar.gz: QupZilla-1.4.3/src/plugins/GreaseMonkey/translations/ja_JP.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja_JP" version="2.0">
<context>
    <name>GM_AddScriptDialog</name>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="14"/>
        <source>GreaseMonkey Installation</source>
        <translation>GreaseMonkeyのインストール</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;GreaseMonkeyのインストール&lt;h3&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="73"/>
        <source>You are about to install this userscript into GreaseMonkey:</source>
        <translation>あなたはこのスクリプトをGreaseMonkeyにインストールしようとしています:</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="86"/>
        <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
        <translation>&lt;b&gt;信頼できるソースからのみインストールしてください！&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="96"/>
        <source>Are you sure you want to install it?</source>
        <translation>本当にインストールしますか？</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.ui" line="114"/>
        <source>Show source code of script</source>
        <translation>スクリプトのソースコードを表示</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="48"/>
        <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;実行するページ&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="52"/>
        <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;実行しないページ&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="82"/>
        <source>Cannot install script</source>
        <translation>スクリプトのインストールに失敗しました</translation>
    </message>
    <message>
        <location filename="../gm_addscriptdialog.cpp" line="85"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos;のインストールに成功しました</translation>
    </message>
</context>
<context>
    <name>GM_Downloader</name>
    <message>
        <location filename="../gm_downloader.cpp" line="144"/>
        <source>&apos;%1&apos; is already installed</source>
        <translation>&apos;%1&apos;は既にインストール済みです</translation>
    </message>
</context>
<context>
    <name>GM_Manager</name>
    <message>
        <location filename="../gm_manager.cpp" line="183"/>
        <source>GreaseMonkey</source>
        <translation>GreaseMonkey</translation>
    </message>
</context>
<context>
    <name>GM_Notification</name>
    <message>
        <location filename="../gm_notification.ui" line="45"/>
        <source>This script can be installed with the GreaseMonkey plugin.</source>
        <translation>このスクリプトをGreasemonkeyでインストールできます。</translation>
    </message>
    <message>
        <location filename="../gm_notification.ui" line="65"/>
        <source>Install</source>
        <translation>インストール</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="49"/>
        <source>Cannot install script</source>
        <translation>スクリプトをインストールできません</translation>
    </message>
    <message>
        <location filename="../gm_notification.cpp" line="57"/>
        <source>&apos;%1&apos; installed successfully</source>
        <translation>&apos;%1&apos;のインストールに成功しました</translation>
    </message>
</context>
<context>
    <name>GM_Settings</name>
    <message>
        <location filename="../settings/gm_settings.ui" line="14"/>
        <source>GreaseMonkey Scripts</source>
        <translation>GreaseMonkey スクリプト</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="51"/>
        <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;GreaseMonkey スクリプト&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="73"/>
        <source>Double clicking script will show additional information</source>
        <translation>スクリプトをダブルクリックすると詳細が表示されます</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="153"/>
        <source>More scripts can be downloaded from</source>
        <translation>さらに多くのスクリプトが以下からインストールできます</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.ui" line="196"/>
        <source>Open scripts directory</source>
        <translation>スクリプトの保存されたフォルダを開く</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="75"/>
        <source>Remove script</source>
        <translation>スクリプトを削除する</translation>
    </message>
    <message>
        <location filename="../settings/gm_settings.cpp" line="76"/>
        <source>Are you sure you want to remove &apos;%1&apos;?</source>
        <translation>本当&apos;%1&apos;を削除してよろしいですか?</translation>
    </message>
</context>
<context>
    <name>GM_SettingsScriptInfo</name>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="19"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="29"/>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="39"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="49"/>
        <source>Start at:</source>
        <translation>Start at:</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="59"/>
        <source>Description:</source>
        <translation>説明</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="69"/>
        <source>Runs at:</source>
        <translation>実行するページ</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.ui" line="79"/>
        <source>Does not run at:</source>
        <translation>実行しないページ</translation>
    </message>
    <message>
        <location filename="../settings/gm_settingsscriptinfo.cpp" line="27"/>
        <source>Script Details of %1</source>
        <translation>%1 の詳細</translation>
    </message>
</context>
</TS>
